CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
63 lines
1.7 KiB
C++
63 lines
1.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include "hip_module_common.hh"
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip/hip_runtime_api.h>
|
|
|
|
#if defined(__HIP_PLATFORM_AMD__) || CUDA_VERSION < CUDA_12000
|
|
|
|
static hipModule_t GetModule() {
|
|
HIP_CHECK(hipFree(nullptr));
|
|
static const auto mg = ModuleGuard::LoadModule("get_tex_ref_module.code");
|
|
return mg.module();
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipModuleGetTexRef_Positive_Basic) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipTexRef tex_ref = nullptr;
|
|
HIP_CHECK(hipModuleGetTexRef(&tex_ref, GetModule(), "tex"));
|
|
REQUIRE(tex_ref != nullptr);
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipModuleGetTexRef_Negative_Parameters) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipModule_t module = GetModule();
|
|
hipTexRef tex_ref = nullptr;
|
|
|
|
SECTION("texRef == nullptr") {
|
|
HIP_CHECK_ERROR(hipModuleGetTexRef(nullptr, module, "tex"), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("name == nullptr") {
|
|
HIP_CHECK_ERROR(hipModuleGetTexRef(&tex_ref, module, nullptr), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("name == non existent texture") {
|
|
HIP_CHECK_ERROR(hipModuleGetTexRef(&tex_ref, module, "non_existent_texture"), hipErrorNotFound);
|
|
}
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipModuleGetTexRef_Negative_Hmod_Is_Nullptr) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipTexRef tex_ref = nullptr;
|
|
|
|
CTX_CREATE();
|
|
HIP_CHECK_ERROR(hipModuleGetTexRef(&tex_ref, nullptr, "tex"), hipErrorInvalidResourceHandle);
|
|
CTX_DESTROY();
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipModuleGetTexRef_Negative_Name_Is_Empty_String) {
|
|
CHECK_IMAGE_SUPPORT
|
|
hipModule_t module = GetModule();
|
|
hipTexRef tex_ref = nullptr;
|
|
|
|
HIP_CHECK_ERROR(hipModuleGetTexRef(&tex_ref, module, ""), hipErrorInvalidValue);
|
|
}
|
|
|
|
#endif
|